#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""

@author: zhandos
"""

import scipy.signal
import numpy as np  
import matplotlib.pylab as plt  
import matplotlib.patches as patches
import os
import matplotlib.ticker as ticker
import matplotlib.ticker as mticker
from matplotlib import rcParams
from scipy.ndimage.filters import gaussian_filter1d
from matplotlib.ticker import MultipleLocator
from scipy.interpolate import BSpline
from scipy import interpolate
from scipy.optimize import curve_fit
from scipy.misc import derivative
import autograd.numpy as np  # Thinly-wrapped numpy
from autograd import grad    # The only autograd function you may ever need
from autograd import elementwise_grad as egrad  # for functions that vectorize over inputs
#from numpy import pi, r_
#import matplotlib.pyplot as plt
from scipy import optimize
from scipy import special
#import sympy as sy
#from sympy import fourier_series, pi, cos, sin
#from sympy.abc import x
from scipy.interpolate import InterpolatedUnivariateSpline

def cm2inch(value):
    return value/2.54

#Figure parameters & Latex Backend for Matplotlib
#Direct input 
plt.rcParams['text.latex.preamble']=[r"\usepackage{lmodern}"]
#Options
params = {'text.usetex' : True,
          'font.size' : 10,
          'font.family' : 'lmodern',
          }
plt.rcParams.update(params) 

f = plt.figure(dpi=200, facecolor='w', edgecolor='k')


#You must select the correct size of the plot in advance
f.set_size_inches(cm2inch(4.*2.5),cm2inch(5.25*1.5))
rcParams["legend.handlelength"] = 0.9
rcParams.update({'figure.autolayout': True})
shade=False
plt.tight_layout()
plt.rc('text', usetex=True)  
plt.rc('font', family='serif') 


for axis in ['top','bottom','left','right']:
  plt.gca().spines[axis].set_linewidth(1)
  plt.gca().tick_params(width=1)


ax1 = plt.subplot(1, 1, 1)

ax1.tick_params(which='minor', length=4)
ax1.tick_params(which='major', length=4)
ax1.tick_params(axis="x", direction="in")
ax1.tick_params(axis="y", direction="in")





my_rs=2.0000

n0=3.0/4.0/np.pi/(my_rs**3)

N_grid=27

jj=1

fname = 'density_q%d.dat' % jj


x, y , z , my_data =np.loadtxt(fname, unpack=True, skiprows=3)

my_data=my_data/n0

ful_range=int(len(my_data))

z_range=int(len(my_data)/N_grid/N_grid)

sum_range=int(N_grid*N_grid)

my_data_Z=np.zeros(z_range)


for j in range(z_range):
    for i in range(int(sum_range*j), int(sum_range*(j+1))): my_data_Z[j]=my_data_Z[j]+my_data[i]
    my_data_Z[j]=my_data_Z[j]/N_grid/N_grid

koef=1

z_scale=4.1118656792442145/3.959574343021436

print(z_scale)
z_cor = np.linspace(0, 1/z_scale, z_range)

data_print=np.vstack((z_cor, (my_data_Z-1)+1)).T
np.savetxt("density_z_q%d.dat" % jj, data_print)



z_cor=np.append(z_cor, 1-z_cor[0])
my_data_Z=np.append(my_data_Z,my_data_Z[0])

ax1.plot(z_cor, (my_data_Z-1)*koef, "-o",color='b', linewidth=1.,  ms=2, zorder=10, label=r'${\rm HSE06}$')


fname = 'density_pbe_q%d.dat' % jj

x, y , z , my_data =np.loadtxt(fname, unpack=True, skiprows=3)

my_data=my_data/n0

ful_range=int(len(my_data))

z_range=int(len(my_data)/N_grid/N_grid)

sum_range=int(N_grid*N_grid)

my_data_Z=np.zeros(z_range)


for j in range(z_range):
    for i in range(int(sum_range*j), int(sum_range*(j+1))): my_data_Z[j]=my_data_Z[j]+my_data[i]
    my_data_Z[j]=my_data_Z[j]/N_grid/N_grid

koef=1

z_scale=4.1118656792442145/3.959574343021436

print(z_scale)
z_cor = np.linspace(0, 1/z_scale, z_range)

data_print=np.vstack((z_cor, (my_data_Z-1)+1)).T

np.savetxt("density_pbe_z_q%d.dat" % jj, data_print)


z_cor=np.append(z_cor, 1-z_cor[0])
my_data_Z=np.append(my_data_Z,my_data_Z[0])

ax1.plot(z_cor, (my_data_Z-1)*koef, "-o",color='r', linewidth=1.,  ms=2, zorder=10, label=r'${\rm PBE}$')




ax1.set_ylabel(r'\textsc{$n/n_0$}', fontsize=10)  
ax1.set_xlabel(r'\textsc{${z/L}$}', fontsize=10)


fig1 = plt.gcf()

plt.show()

fig1.savefig('density_rs2_t1.jpg',  bbox_inches='tight', dpi=300)

